//
// TCPServerConnectionFactory.cpp
//
// Library: Net
// Package: TCPServer
// Module:  TCPServerConnectionFactory
//
// Copyright (c) 2005-2006, Applied Informatics Software Engineering GmbH.
// and Contributors.
//
// SPDX-License-Identifier:	BSL-1.0
//


#include "Poco/Net/TCPServerConnectionFactory.h"


namespace Poco {
namespace Net {


TCPServerConnectionFactory::TCPServerConnectionFactory():
	_stopped(false)
{
}


TCPServerConnectionFactory::~TCPServerConnectionFactory()
{
}


} } // namespace Poco::Net
